@@ -161,10 +161,8 @@ covW <- function(data, groups)
         gsizes <- as.vector(tapply(groups, groups, length))
         covWithin <- 0
         for (i in 1:nlev)
-            if (gsizes[i] > 1)
+            if (gsizes[i] > 1) 
                 covWithin <- covWithin + (cov(data[groups==glev[i],]) * (gsizes[i]-1))
-            else
-                covWithin <- covWithin+diag(1,ncol(data))
         
         covWithin <- covWithin/(ndata - nlev)
         return(covWithin)
